<?php
/**
 * Core Theme Functions.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Dorya
 * @since 		 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
  * Shim for wp_body_open
  *
  * @since  1.0.0
  */
if ( ! function_exists( 'wp_body_open' ) ) {
  function wp_body_open() {
    do_action( 'wp_body_open' );
  }
}

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function dorya_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- assets/js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'dorya_skip_link_focus_fix' );


/**
	* Check if page built with Elementor
	*
	* @since  1.0.0
	*/
function dorya_is_elementor_page() {
	$elementor_page = get_post_meta( get_the_ID(), '_elementor_edit_mode', true );

	if ( is_search() || is_archive() ) {
		return false;
	}

	if ( (bool)$elementor_page ) {
		return true;
	} else {
		return false;
	}	
}


/**
* Gutenberg Check
*
* @since 1.0.0
*/
function dorya_is_gutenberg() {
	return function_exists( 'register_block_type' ); 
}


/**
	* Check if it's CPT archive
	*
	* @since  1.0.0
	*/
function dorya_is_cpt( $cpt ) {
	return ( is_tax( "{$cpt}_categories" ) || is_post_type_archive( $cpt ) );	
}


if ( ! function_exists( 'dorya_custom_post_type_nav_classes' ) ) {
	/**
	* Fix for current_page_parent menu class
	*
	* @since 1.0.0
	*/
	function dorya_custom_post_type_nav_classes( $classes, $item ) {
		$cpt = array( 'projects' );
		if ( ( is_post_type_archive( $cpt ) || is_singular( $cpt ) )
		&& get_post_meta( $item->ID, '_menu_item_object_id', true ) == get_option( 'page_for_posts' ) ) {
			$classes = array_diff( $classes, array( 'current_page_parent' ) );
		}
		return $classes;
	}
}
add_filter( 'nav_menu_css_class', 'dorya_custom_post_type_nav_classes', 10, 2 );



/**
 * Custom excerpt length
 */
function dorya_custom_excerpt_length( $length ) {
	if ( is_admin() ) {
		return;
	}

	$excerpt_length = get_theme_mod( 'dorya_settings_posts_excerpt_settings', 30 );
	return $excerpt_length;
}
add_filter( 'excerpt_length', 'dorya_custom_excerpt_length' );


if ( ! function_exists( 'dorya_cpt_pagination_rewrite' ) ) {
	/**
	 * Fix pagination on cpt archive pages
	 *
	 * @since 1.0.0
	 */
	function dorya_cpt_pagination_rewrite() {
		$permalinks = get_option( 'dorya_permalinks' );

		if ( ! $permalinks ) {
			return;
		}
		
		$projects_base = empty( $permalinks['projects_base'] ) ? 'projects' : $permalinks['projects_base'];
		add_rewrite_rule( $projects_base . '/page/?([0-9]{1,})/?$', 'index.php?pagename=' . $projects_base . '&paged=$matches[1]', 'top');
	}
	add_action('init', 'dorya_cpt_pagination_rewrite');
}


if ( ! function_exists( 'dorya_sidebar' ) ) {
	/**
	* Get sidebar
	*
	* @since 1.0.0
	*/
	function dorya_sidebar( $sidebar = '' ) {
		if ( ! is_active_sidebar( $sidebar ) ) return;
		?>
			<aside class="sidebar col-lg">
				<div itemtype="https://schema.org/WPSideBar" itemscope="itemscope" id="secondary" class="widget-area" role="complementary">
					<?php dorya_sidebar_before(); ?>
					<?php dynamic_sidebar( $sidebar ); ?>
					<?php dorya_sidebar_after(); ?>
				</div> <!-- #secondary -->
			</aside>
		<?php
	}
}


if ( ! function_exists( 'dorya_is_active_sidebar' ) ) {
	/**
	* Check if sidebar is active
	* @param string sidebar name
	* @param string sidebar type
	* @param string default layout
	* @return bool
	* @since 1.0.0
	*/
	function dorya_is_active_sidebar( $sidebar = '', $layout = '', $default = 'fullwidth' ) {
		if ( 'fullwidth' !== dorya_layout_type( $layout, $default ) && is_active_sidebar( 'dorya-' . $sidebar . '-sidebar' ) ) {
			return true;
		}
	}
}


if ( ! function_exists( 'dorya_layout_type' ) ) {
	/**
	 * Check layout type based on customizer and meta settings
	 * @return string $type Layout type
	 */
	function dorya_layout_type( $type, $default = 'fullwidth' ) {
		$layout = '';
		$meta = get_post_meta( get_the_ID(), '_dorya_page_layout', true );
		$page_for_posts = get_option( 'page_for_posts' );

		if ( is_home() && $page_for_posts ) {
			$meta = get_post_meta( $page_for_posts, '_dorya_page_layout', true );
		}

		if ( is_archive() || is_404() || is_search() || is_home() ) {
			$meta = '';
		}

		if ( 'left-sidebar' == get_theme_mod( 'dorya_settings_' . $type .  '_layout_type', $default ) ) {
			$layout = ( $meta ) ? $meta : 'left-sidebar';		
		}

		if ( 'right-sidebar' == get_theme_mod( 'dorya_settings_' . $type .  '_layout_type', $default ) ) {
			$layout = ( $meta ) ? $meta : 'right-sidebar';
		}

		if ( 'fullwidth' == get_theme_mod( 'dorya_settings_' . $type .  '_layout_type', $default ) ) {			
			$layout = ( $meta ) ? $meta : 'fullwidth';
		}	

		return $layout;
	}
}


/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function dorya_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'dorya-group-blog';
	}

	// Page Layout Class
	if ( is_page() ) {
		$classes[] = 'dorya-' . dorya_layout_type( 'page' );
	}

	// Blog Layout Class
	if ( is_home() ) {
		$classes[] = 'dorya-' . dorya_layout_type( 'blog', 'fullwidth' );
	}

	// Single Post Layout Class
	if ( is_single() ) {
		$classes[] = 'dorya-' . dorya_layout_type( 'single_post' );
	}
    
	// Archives Layout Class
	if ( is_archive() ) {
		$classes[] = 'dorya-' . dorya_layout_type( 'archive' );
	}

	// Search Layout Class
	if ( is_search() ) {
		$classes[] = 'dorya-' . dorya_layout_type( 'search_results' );	
	}

	$classes[] = '';

	return $classes;
}
add_filter( 'body_class', 'dorya_body_classes' );


/**
 * Adds custom admin classes.
 *
 * @param string $classes Classes for the body element.
 * @return string
 */
function dorya_admin_body_classes( $classes ) {

	$screen = get_current_screen();

	// Add blog layout class
	if( $screen->id === "post" ) {
		$classes = 'dorya-' . dorya_layout_type( 'single_post' );
	}

	// Add page layout class
	if( $screen->id === "page" ) {
		$classes = 'dorya-' . dorya_layout_type( 'page' );
	}
	
	return $classes;
}
add_filter( 'admin_body_class', 'dorya_admin_body_classes' );