<?php
/**
 * Theme setup.
 *
 * @package Dorya
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}


if ( ! function_exists( 'dorya_setup' ) ) :
	/**
	* Sets up theme defaults and registers support for various WordPress features.
	*
	* Note that this function is hooked into the after_setup_theme hook, which
	* runs before the init hook. The init hook is too late for some features, such
	* as indicating support for post thumbnails.
	*/
	function dorya_setup() {

		load_theme_textdomain( 'dorya', DORYA_DIR . '/languages' );

		// Enable theme support
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption', ) );
		add_theme_support( 'post-formats', array( 'video', 'audio' ) );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'custom-background', apply_filters( 'dorya_custom_background_args', array(
			'default-color' => '#ffffff',
			'default-image' => '',
		) ) );

		// Gutenberg
		add_theme_support( 'align-wide' );
		add_theme_support( 'responsive-embeds' );

		add_theme_support( 'editor-styles' );
		add_editor_style();

		add_theme_support( 'custom-spacing' );
		add_theme_support( 'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Primary', 'dorya' ),
				'slug' => 'primary',
				'color' => get_theme_mod( 'dorya_settings_primary_color', '#0052f8' ),
			),
			array(
				'name' => esc_html__( 'Secondary', 'dorya' ),
				'slug' => 'secondary',
				'color' => get_theme_mod( 'dorya_settings_secondary_color', '#ffc62d' ),
			),			
			array(
				'name' => esc_html__( 'Tertiary', 'dorya' ),
				'slug' => 'tertiary',
				'color' => get_theme_mod( 'dorya_settings_tertiary_color', '#11d5ed' ),
			),
			array(
				'name' => esc_html__( 'Quaternary', 'dorya' ),
				'slug' => 'quaternary',
				'color' => get_theme_mod( 'dorya_settings_background_light_color', '#f8f9fa' ),
			)
		) );


		// Thumbnails
		add_image_size( 'dorya_thumbnail', 96, 96, true );
		add_image_size( 'dorya_featured_medium', 1054, 0, false );
		add_image_size( 'dorya_featured_large', 1660, 934, true );
		
		// Nav menus
		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Primary Menu', 'dorya' ),
			'footer-bottom-menu' => esc_html__( 'Footer Bottom Menu', 'dorya' ),
		) );

		// Disable Elementor onboarding
		update_option( 'elementor_onboarded', 1 );

		// Disable Kirki telemetry
		add_filter( 'kirki_telemetry', '__return_false' );

		// Allow shorcodes in text widgets
		add_filter( 'widget_text', 'do_shortcode' );

	}
endif; // theme_setup
add_action( 'after_setup_theme', 'dorya_setup' );


// Update Elementor Defaults
if ( 1 != get_option( 'dorya_elementor_defaults', 0 ) ) {
	add_option( 'dorya_elementor_defaults', 0 );
}

/**
* Update Elementor defaults.
*/
function dorya_update_elementor_defaults() {
	if ( 1 != get_option( 'dorya_elementor_defaults' ) ) {
		update_option( 'elementor_cpt_support', array(
			'post',
			'page',
			'projects',
			'theme_template'
		) );

		update_option( '_elementor_editor_upgrade_notice_dismissed', time() + '9999999999' );
		update_option( 'elementor_disable_color_schemes', 'yes' );
		update_option( 'elementor_disable_typography_schemes', 'yes' );
		update_option( 'elementor_unfiltered_files_upload', 1 );
		update_option( 'elementor_experiment-e_lazyload', 'active' );
		update_option( 'elementor_experiment-e_font_icon_svg', 'active' );
		update_option( 'dorya_elementor_defaults', 1 );
	}
}
add_action( 'init', 'dorya_update_elementor_defaults' );


/**
* Register widget areas.
*/
function dorya_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'dorya' ),
		'id'            => 'dorya-blog-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Page Sidebar', 'dorya' ),
		'id'            => 'dorya-page-sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer CTA', 'dorya' ),
		'id'            => 'dorya-footer-cta',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'dorya' ),
		'id'            => 'dorya-footer-col-1',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	if (
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-50-25-25' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-5' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-4' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-3' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-2' )
	{
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Column 2', 'dorya' ),
			'id'            => 'dorya-footer-col-2',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
	
	if (
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-50-25-25' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-5' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-4' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-3' )
	{
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Column 3', 'dorya' ),
			'id'            => 'dorya-footer-col-3',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
	
	if (
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-5' ||
		get_theme_mod( 'dorya_settings_footer_columns', 'footer-col-3' ) == 'footer-col-4' )
	{
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Column 4', 'dorya' ),
			'id'            => 'dorya-footer-col-4',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}	

}
add_action( 'widgets_init', 'dorya_widgets_init' );